abacusai.api_class — AbacusAI documentation

# `abacusai.api_class`

## Submodules

- `abacusai.api_class.abstract`
- `abacusai.api_class.ai_agents`
- `abacusai.api_class.ai_chat`
- `abacusai.api_class.batch_prediction`
- `abacusai.api_class.blob_input`
- `abacusai.api_class.dataset`
- `abacusai.api_class.dataset_application_connector`
- `abacusai.api_class.document_retriever`
- `abacusai.api_class.enums`
- `abacusai.api_class.feature_group`
- `abacusai.api_class.model`
- `abacusai.api_class.monitor`
- `abacusai.api_class.monitor_alert`
- `abacusai.api_class.project`
- `abacusai.api_class.python_functions`
- `abacusai.api_class.refresh`

## Package Contents

### Classes

`ApiClass` | Helper class that provides a standard way to create an ABC using
`FieldDescriptor` | Configs for vector store indexing.
`ApiClass` | Helper class that provides a standard way to create an ABC using
`HotkeyPrompt` | A config class for a Data Science Co-Pilot Hotkey
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`BatchPredictionArgs` | Helper class that provides a standard way to create an ABC using
`AnomalyOutliersBatchPredictionArgs` | Batch Prediction Config for the ANOMALY_OUTLIERS problem type
`ForecastingBatchPredictionArgs` | Batch Prediction Config for the FORECASTING problem type
`NamedEntityExtractionBatchPredictionArgs` | Batch Prediction Config for the NAMED_ENTITY_EXTRACTION problem type
`PersonalizationBatchPredictionArgs` | Batch Prediction Config for the PERSONALIZATION problem type
`PredictiveModelingBatchPredictionArgs` | Batch Prediction Config for the PREDICTIVE_MODELING problem type
`PretrainedModelsBatchPredictionArgs` | Batch Prediction Config for the PRETRAINED_MODELS problem type
`SentenceBoundaryDetectionBatchPredictionArgs` | Batch Prediction Config for the SENTENCE_BOUNDARY_DETECTION problem type
`ThemeAnalysisBatchPredictionArgs` | Batch Prediction Config for the THEME_ANALYSIS problem type
`ChatLLMBatchPredictionArgs` | Batch Prediction Config for the ChatLLM problem type
`TrainablePlugAndPlayBatchPredictionArgs` | Batch Prediction Config for the TrainablePlugAndPlay problem type
`_BatchPredictionArgsFactory` | Helper class that provides a standard way to create an ABC using
`ApiClass` | Helper class that provides a standard way to create an ABC using
`BlobInput` | Binary large object input data.
`ApiClass` | Helper class that provides a standard way to create an ABC using
`OcrMode` | Generic enumeration.
`ParsingConfig` | Helper class that provides a standard way to create an ABC using
`DocumentProcessingConfig` | Document processing configuration.
`IncrementalDatabaseConnectorConfig` | Config information for incremental datasets from database connectors
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`DatasetConfig` | Helper class that provides a standard way to create an ABC using
`ConfluenceDatasetConfig` | Dataset config for Confluence Application Connector
`GoogleAnalyticsDatasetConfig` | Dataset config for Google Analytics Application Connector
`GoogleDriveDatasetConfig` | Dataset config for Google Drive Application Connector
`JiraDatasetConfig` | Dataset config for Jira Application Connector
`OneDriveDatasetConfig` | Dataset config for OneDrive Application Connector
`SharepointDatasetConfig` | Dataset config for Sharepoint Application Connector
`ZendeskDatasetConfig` | Dataset config for Zendesk Application Connector
`AbacusUsageMetricsDatasetConfig` | Dataset config for Abacus Usage Metrics Application Connector
`_DatasetConfigFactory` | Helper class that provides a standard way to create an ABC using
`ApiClass` | Helper class that provides a standard way to create an ABC using
`VectorStoreTextEncoder` | Generic enumeration.
`VectorStoreConfig` | Configs for vector store indexing.
`DocumentRetrieverConfig` | Configs for document retriever.
`ApiEnum` | Generic enumeration.
`ProblemType` | Generic enumeration.
`RegressionObjective` | Generic enumeration.
`RegressionTreeHPOMode` | Generic enumeration.
`PartialDependenceAnalysis` | Generic enumeration.
`RegressionAugmentationStrategy` | Generic enumeration.
`RegressionTargetTransform` | Generic enumeration.
`RegressionTypeOfSplit` | Generic enumeration.
`RegressionTimeSplitMethod` | Generic enumeration.
`RegressionLossFunction` | Generic enumeration.
`ExplainerType` | Generic enumeration.
`SamplingMethodType` | Generic enumeration.
`MergeMode` | Generic enumeration.
`FillLogic` | Generic enumeration.
`BatchSize` | Generic enumeration.
`HolidayCalendars` | Generic enumeration.
`FileFormat` | Generic enumeration.
`ExperimentationMode` | Generic enumeration.
`PersonalizationTrainingMode` | Generic enumeration.
`PersonalizationObjective` | Generic enumeration.
`ForecastingObjective` | Generic enumeration.
`ForecastingFrequency` | Generic enumeration.
`ForecastingDataSplitType` | Generic enumeration.
`ForecastingLossFunction` | Generic enumeration.
`ForecastingLocalScaling` | Generic enumeration.
`ForecastingFillMethod` | Generic enumeration.
`ForecastingQuanitlesExtensionMethod` | Generic enumeration.
`TimeseriesAnomalyDataSplitType` | Generic enumeration.
`TimeseriesAnomalyTypeOfAnomaly` | Generic enumeration.
`NERObjective` | Generic enumeration.
`NERModelType` | Generic enumeration.
`NLPDocumentFormat` | Generic enumeration.
`SentimentType` | Generic enumeration.
`ClusteringImputationMethod` | Generic enumeration.
`ConnectorType` | Generic enumeration.
`ApplicationConnectorType` | Generic enumeration.
`PythonFunctionArgumentType` | Generic enumeration.
`PythonFunctionOutputArgumentType` | Generic enumeration.
`VectorStoreTextEncoder` | Generic enumeration.
`LLMName` | Generic enumeration.
`MonitorAlertType` | Generic enumeration.
`FeatureDriftType` | Generic enumeration.
`DataIntegrityViolationType` | Generic enumeration.
`BiasType` | Generic enumeration.
`AlertActionType` | Generic enumeration.
`PythonFunctionType` | Generic enumeration.
`EvalArtifactType` | Generic enumeration.
`FieldDescriptorType` | Generic enumeration.
`OcrMode` | Generic enumeration.
`DataType` | Generic enumeration.
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`SamplingConfig` | An abstract class for the sampling config of a feature group
`NSamplingConfig` | The number of distinct values of the key columns to include in the sample, or number of rows if key columns not specified.
`PercentSamplingConfig` | The fraction of distinct values of the feature group to include in the sample.
`_SamplingConfigFactory` | Helper class that provides a standard way to create an ABC using
`MergeConfig` | An abstract class for the merge config of a feature group
`LastNMergeConfig` | Merge LAST N chunks/versions of an incremental dataset.
`TimeWindowMergeConfig` | Merge rows within a given timewindow of the most recent timestamp
`_MergeConfigFactory` | Helper class that provides a standard way to create an ABC using
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`TrainingConfig` | Helper class that provides a standard way to create an ABC using
`PersonalizationTrainingConfig` | Training config for the PERSONALIZATION problem type
`RegressionTrainingConfig` | Training config for the PREDICTIVE_MODELING problem type
`ForecastingTrainingConfig` | Training config for the FORECASTING problem type
`NamedEntityExtractionTrainingConfig` | Training config for the NAMED_ENTITY_EXTRACTION problem type
`NaturalLanguageSearchTrainingConfig` | Training config for the NATURAL_LANGUAGE_SEARCH problem type
`ChatLLMTrainingConfig` | Training config for the CHAT_LLM problem type
`SentenceBoundaryDetectionTrainingConfig` | Training config for the SENTENCE_BOUNDARY_DETECTION problem type
`SentimentDetectionTrainingConfig` | Training config for the SENTIMENT_DETECTION problem type
`DocumentClassificationTrainingConfig` | Training config for the DOCUMENT_CLASSIFICATION problem type
`DocumentSummarizationTrainingConfig` | Training config for the DOCUMENT_SUMMARIZATION problem type
`DocumentVisualizationTrainingConfig` | Training config for the DOCUMENT_VISUALIZATION problem type
`ClusteringTrainingConfig` | Training config for the CLUSTERING problem type
`ClusteringTimeseriesTrainingConfig` | Training config for the CLUSTERING_TIMESERIES problem type
`EventAnomalyTrainingConfig` | Training config for the EVENT_ANOMALY problem type
`TimeseriesAnomalyTrainingConfig` | Training config for the TS_ANOMALY problem type
`CumulativeForecastingTrainingConfig` | Training config for the CUMULATIVE_FORECASTING problem type
`ThemeAnalysisTrainingConfig` | Training config for the THEME ANALYSIS problem type
`AIAgentTrainingConfig` | Training config for the AI_AGENT problem type
`CustomTrainedModelTrainingConfig` | Training config for the CUSTOM_TRAINED_MODEL problem type
`CustomAlgorithmTrainingConfig` | Training config for the CUSTOM_ALGORITHM problem type
`OptimizationTrainingConfig` | Training config for the OPTIMIZATION problem type
`_TrainingConfigFactory` | Helper class that provides a standard way to create an ABC using
`DeployableAlgorithm` | Algorithm that can be deployed to a model.
`ApiClass` | Helper class that provides a standard way to create an ABC using
`ForecastingMonitorConfig` | Helper class that provides a standard way to create an ABC using
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`AlertConditionConfig` | Helper class that provides a standard way to create an ABC using
`AccuracyBelowThresholdConditionConfig` | Accuracy Below Threshold Condition Config for Monitor Alerts
`FeatureDriftConditionConfig` | Feature Drift Condition Config for Monitor Alerts
`TargetDriftConditionConfig` | Target Drift Condition Config for Monitor Alerts
`HistoryLengthDriftConditionConfig` | History Length Drift Condition Config for Monitor Alerts
`DataIntegrityViolationConditionConfig` | Data Integrity Violation Condition Config for Monitor Alerts
`BiasViolationConditionConfig` | Bias Violation Condition Config for Monitor Alerts
`PredictionCountConditionConfig` | Deployment Prediction Condition Config for Deployment Alerts. By default we monitor if predictions made over a time window has reduced significantly.
`_AlertConditionConfigFactory` | Helper class that provides a standard way to create an ABC using
`AlertActionConfig` | Helper class that provides a standard way to create an ABC using
`EmailActionConfig` | Email Action Config for Monitor Alerts
`_AlertActionConfigFactory` | Helper class that provides a standard way to create an ABC using
`MonitorThresholdConfig` | Monitor Threshold Config for Monitor Alerts
`ApiClass` | Helper class that provides a standard way to create an ABC using
`FeatureMappingConfig` | Helper class that provides a standard way to create an ABC using
`ProjectFeatureGroupTypeMappingsConfig` | Helper class that provides a standard way to create an ABC using
`ApiClass` | Helper class that provides a standard way to create an ABC using
`PythonFunctionArgument` | A config class for python function arguments
`OutputVariableMapping` | A config class for python function arguments
`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`FeatureGroupExportConfig` | Helper class that provides a standard way to create an ABC using
`FileConnectorExportConfig` | Helper class that provides a standard way to create an ABC using
`DatabaseConnectorExportConfig` | Helper class that provides a standard way to create an ABC using
`_FeatureGroupExportConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.FieldDescriptor

  Bases: `abacusai.api_class.abstract.ApiClass`

  Configs for vector store indexing.

  Parameters:

    - field (str) – The field to be extracted. This will be used as the key in the response.

    - description (str) – The description of this field. If not included, the response_field will be used.

    - example_extraction (Union[str, int, bool, float]) – An example of this extracted field.

    - type (enums.FieldDescriptorType) – The type of this field. If not provided, the default type is STRING.

  field: str
  description: str
  example_extraction: str | int | bool | float | list | dict
  type: abacusai.api_class.enums.FieldDescriptorType

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.HotkeyPrompt

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for a Data Science Co-Pilot Hotkey

  Parameters:

    - prompt (str) – The prompt to send to Data Science Co-Pilot

    - title (str) – A short, descriptive title for the prompt. If not provided, one will be automatically generated.

  prompt: str
  title: str

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.BatchPredictionArgs

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  _support_kwargs: bool
  kwargs: dict
  problem_type: abacusai.api_class.enums.ProblemType
  classmethod _get_builder()

class abacusai.api_class.AnomalyOutliersBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the ANOMALY_OUTLIERS problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - threshold (float) – The threshold for detecting an anomaly. Range: [0.8, 0.99]

    - explain_predictions (bool) – If True, calculates explanations for the predicted values along with predictions.

  for_eval: bool
  threshold: float
  explain_predictions: bool
  __post_init__()

class abacusai.api_class.ForecastingBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the FORECASTING problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation

    - predictions_start_date (str) – The start date for predictions.

    - use_prediction_offset (bool) – If True, use prediction offset.

    - start_date_offset (int) – Sets prediction start date as this offset relative to the prediction start date.

    - forecasting_horizon (int) – The number of timestamps to predict in the future. Range: [1, 1000].

    - item_attributes_to_include_in_the_result (list) – List of columns to include in the prediction output.

    - explain_predictions (bool) – If True, calculates explanations for the forecasted values along with predictions.

    - automate_monitoring (bool) – If True, creates a monitor to calculate the drift for the batch prediction.

  for_eval: bool
  predictions_start_date: str
  use_prediction_offset: bool
  start_date_offset: int
  forecasting_horizon: int
  item_attributes_to_include_in_the_result: list
  explain_predictions: bool
  automate_monitoring: bool
  __post_init__()

class abacusai.api_class.NamedEntityExtractionBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the NAMED_ENTITY_EXTRACTION problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - verbose_predictions (bool) – Return prediction inputs, predicted annotations and token label probabilities.

  for_eval: bool
  verbose_predictions: bool
  __post_init__()

class abacusai.api_class.PersonalizationBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PERSONALIZATION problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - number_of_items (int) – Number of items to recommend.

    - result_columns (list) – List of columns to include in the prediction output.

    - score_field (str) – If specified, relative item scores will be returned using a field with this name

  for_eval: bool
  number_of_items: int
  item_attributes_to_include_in_the_result: list
  score_field: str
  __post_init__()

class abacusai.api_class.PredictiveModelingBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PREDICTIVE_MODELING problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - explainer_type (enums.ExplainerType) – The type of explainer to use to generate explanations on the batch prediction.

    - number_of_samples_to_use_for_explainer (int) – Number Of Samples To Use For Kernel Explainer.

    - include_multi_class_explanations (bool) – If True, Includes explanations for all classes in multi-class classification.

    - features_considered_constant_for_explanations (str) – Comma separate list of fields to treat as constant in SHAP explanations.

    - importance_of_records_in_nested_columns (str) – Returns importance of each index in the specified nested column instead of SHAP column explanations.

    - explanation_filter_lower_bound (float) – If set explanations will be limited to predictions above this value, Range: [0, 1].

    - explanation_filter_upper_bound (float) – If set explanations will be limited to predictions below this value, Range: [0, 1].

    - bound_label (str) – For classification problems specifies the label to which the explanation bounds are applied.

    - output_columns (list) – A list of column names to include in the prediction result.

    - explain_predictions (bool) – If True, calculates explanations for the predicted values along with predictions.

    - automate_monitoring (bool) – If True, creates a monitor to calculate the drift for the batch prediction.

  for_eval: bool
  explainer_type: abacusai.api_class.enums.ExplainerType
  number_of_samples_to_use_for_explainer: int
  include_multi_class_explanations: bool
  features_considered_constant_for_explanations: str
  importance_of_records_in_nested_columns: str
  explanation_filter_lower_bound: float
  explanation_filter_upper_bound: float
  explanation_filter_label: str
  output_columns: list
  explain_predictions: bool
  automate_monitoring: bool
  __post_init__()

class abacusai.api_class.PretrainedModelsBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PRETRAINED_MODELS problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - files_output_location_prefix (str) – The output location prefix for the files.

    - channel_id_to_label_map (str) – JSON string for the map from channel ids to their labels.

  for_eval: bool
  files_output_location_prefix: str
  channel_id_to_label_map: str
  __post_init__()

class abacusai.api_class.SentenceBoundaryDetectionBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the SENTENCE_BOUNDARY_DETECTION problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation

    - explode_output (bool) – Explode data so there is one sentence per row.

  for_eval: bool
  explode_output: bool
  __post_init__()

class abacusai.api_class.ThemeAnalysisBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the THEME_ANALYSIS problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - analysis_frequency (str) – The length of each analysis interval.

    - start_date (str) – The end point for predictions.

    - analysis_days (int) – How many days to analyze.

  for_eval: bool
  analysis_frequency: str
  start_date: str
  analysis_days: int
  __post_init__()

class abacusai.api_class.ChatLLMBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the ChatLLM problem type

  Parameters:

    for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

  for_eval: bool
  __post_init__()

class abacusai.api_class.TrainablePlugAndPlayBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the TrainablePlugAndPlay problem type

  Parameters:

    automate_monitoring (bool) – If True, creates a monitor to calculate the drift for the batch prediction.

  for_eval: bool
  automate_monitoring: bool
  __post_init__()

class abacusai.api_class._BatchPredictionArgsFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'problem_type'
  config_class_map

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.BlobInput

  Bases: `abacusai.api_class.abstract.ApiClass`

  Binary large object input data.

  Parameters:

    - filename (str) – The original filename of the blob.

    - contents (bytes) – The binary contents of the blob.

    - mime_type (str) – The mime type of the blob.

    - size (int) – The size of the blob in bytes.

  filename: str
  contents: bytes
  mime_type: str
  size: int
  classmethod from_local_file(file_path)
    Parameters:

      file_path (str) –

    Return type:

      BlobInput

  classmethod from_contents(contents, filename=None, mime_type=None)
    Parameters:

      - contents (bytes) –

      - filename (str) –

      - mime_type (str) –

    Return type:

      BlobInput

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.OcrMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEFAULT = 'DEFAULT'
  LAYOUT = 'LAYOUT'
  SCANNED = 'SCANNED'
  COMPREHENSIVE = 'COMPREHENSIVE'
  COMPREHENSIVE_V2 = 'COMPREHENSIVE_V2'
  COMPREHENSIVE_TABLE_MD = 'COMPREHENSIVE_TABLE_MD'

class abacusai.api_class.ParsingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  escape: str
  csv_delimiter: str
  file_path_with_schema: str

class abacusai.api_class.DocumentProcessingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Document processing configuration.

  Parameters:

    - extract_bounding_boxes (bool) – Whether to perform OCR and extract bounding boxes. If False, no OCR will be done but only the embedded text from digital documents will be extracted. Defaults to False.

    - ocr_mode (OcrMode) – OCR mode. There are different OCR modes available for different kinds of documents and use cases. This option only takes effect when extract_bounding_boxes is True.

    - use_full_ocr (bool) – Whether to perform full OCR. If True, OCR will be performed on the full page. If False, OCR will be performed on the non-text regions only. By default, it will be decided automatically based on the OCR mode and the document type. This option only takes effect when extract_bounding_boxes is True.

    - remove_header_footer (bool) – Whether to remove headers and footers. Defaults to False. This option only takes effect when extract_bounding_boxes is True.

    - remove_watermarks (bool) – Whether to remove watermarks. By default, it will be decided automatically based on the OCR mode and the document type. This option only takes effect when extract_bounding_boxes is True.

    - convert_to_markdown (bool) – Whether to convert extracted text to markdown. Defaults to False. This option only takes effect when extract_bounding_boxes is True.

  extract_bounding_boxes: bool = False
  ocr_mode: abacusai.api_class.enums.OcrMode
  use_full_ocr: bool
  remove_header_footer: bool = False
  remove_watermarks: bool = True
  convert_to_markdown: bool = False

class abacusai.api_class.IncrementalDatabaseConnectorConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Config information for incremental datasets from database connectors

  Parameters:

    timestamp_column (str) – If dataset is incremental, this is the column name of the required column in the dataset. This column must contain timestamps in descending order which are used to determine the increments of the incremental dataset.

  timestamp_column: str

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.DatasetConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  application_connector_type: abacusai.api_class.enums.ApplicationConnectorType
  classmethod _get_builder()

class abacusai.api_class.ConfluenceDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Confluence Application Connector :param pull_attachments: Whether to pull attachments for each page :type pull_attachments: bool, optional :param space_key: The space key to fetch pages from :type space_key: str, optional

  pull_attachments: bool
  space_key: str
  __post_init__()

class abacusai.api_class.GoogleAnalyticsDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Google Analytics Application Connector

  Parameters:

    - location (str) – The view id of the report in the connector to fetch

    - start_timestamp (int, optional) – Unix timestamp of the start of the period that will be queried

    - end_timestamp (int, optional) – Unix timestamp of the end of the period that will be queried

  location: str
  start_timestamp: int
  end_timestamp: int
  __post_init__()

class abacusai.api_class.GoogleDriveDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Google Drive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.JiraDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Jira Application Connector

  Parameters:

    - jql (str) – The JQL query for fetching issues

    - custom_fields (list, optional) – A list of custom fields to include in the dataset

    - include_comments (bool, optional) – Fetch comments for each issue

    - include_watchers (bool, optional) – Fetch watchers for each issue

  jql: str
  custom_fields: list
  include_comments: bool
  include_watchers: bool
  __post_init__()

class abacusai.api_class.OneDriveDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for OneDrive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.SharepointDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Sharepoint Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.ZendeskDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Zendesk Application Connector

  __post_init__()

class abacusai.api_class.AbacusUsageMetricsDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Abacus Usage Metrics Application Connector

  Parameters:

    include_entire_conversation_history (bool) – Whether to show the entire history for this deployment conversation

  include_entire_conversation_history: bool
  __post_init__()

class abacusai.api_class._DatasetConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'application_connector_type'
  config_class_map

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.VectorStoreTextEncoder

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  E5 = 'E5'
  OPENAI = 'OPENAI'
  SENTENCE_BERT = 'SENTENCE_BERT'
  E5_SMALL = 'E5_SMALL'

class abacusai.api_class.VectorStoreConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Configs for vector store indexing.

  Parameters:

    - chunk_size (int) – The size of text chunks in the vector store.

    - chunk_overlap_fraction (float) – The fraction of overlap between chunks.

    - text_encoder (VectorStoreTextEncoder) – Encoder used to index texts from the documents.

    - chunk_size_factors (list) – Chunking data with multiple sizes. The specified list of factors are used to calculate more sizes, in addition to chunk_size.

    - score_multiplier_column (str) – If provided, will use the values in this metadata column to modify the relevance score of returned chunks for all queries.

  chunk_size: int
  chunk_overlap_fraction: float
  text_encoder: abacusai.api_class.enums.VectorStoreTextEncoder
  chunk_size_factors: list
  score_multiplier_column: str

class abacusai.api_class.DocumentRetrieverConfig

  Bases: `VectorStoreConfig`

  Configs for document retriever.

class abacusai.api_class.ApiEnum

  Bases: `enum.Enum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  __eq__(other)

    Return self==value.

  __hash__()

    Return hash(self).

class abacusai.api_class.ProblemType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AI_AGENT = 'ai_agent'
  ANOMALY_OUTLIERS = 'anomaly'
  EVENT_ANOMALY = 'event_anomaly'
  CLUSTERING = 'clustering'
  CLUSTERING_TIMESERIES = 'clustering_timeseries'
  CUMULATIVE_FORECASTING = 'cumulative_forecasting'
  NAMED_ENTITY_EXTRACTION = 'nlp_ner'
  NATURAL_LANGUAGE_SEARCH = 'nlp_search'
  CHAT_LLM = 'chat_llm'
  SENTENCE_BOUNDARY_DETECTION = 'nlp_sentence_boundary_detection'
  SENTIMENT_DETECTION = 'nlp_sentiment'
  DOCUMENT_CLASSIFICATION = 'nlp_classification'
  DOCUMENT_SUMMARIZATION = 'nlp_summarization'
  DOCUMENT_VISUALIZATION = 'nlp_document_visualization'
  PERSONALIZATION = 'personalization'
  PREDICTIVE_MODELING = 'regression'
  FINETUNED_LLM = 'finetuned_llm'
  FORECASTING = 'forecasting'
  CUSTOM_TRAINED_MODEL = 'plug_and_play'
  CUSTOM_ALGORITHM = 'trainable_plug_and_play'
  FEATURE_STORE = 'feature_store'
  IMAGE_CLASSIFICATION = 'vision_classification'
  OBJECT_DETECTION = 'vision_object_detection'
  IMAGE_VALUE_PREDICTION = 'vision_regression'
  MODEL_MONITORING = 'model_monitoring'
  LANGUAGE_DETECTION = 'language_detection'
  OPTIMIZATION = 'optimization'
  PRETRAINED_MODELS = 'pretrained'
  THEME_ANALYSIS = 'theme_analysis'
  TS_ANOMALY = 'ts_anomaly'

class abacusai.api_class.RegressionObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUC = 'auc'
  ACCURACY = 'acc'
  LOG_LOSS = 'log_loss'
  PRECISION = 'precision'
  RECALL = 'recall'
  F1_SCORE = 'fscore'
  MAE = 'mae'
  MAPE = 'mape'
  WAPE = 'wape'
  RMSE = 'rmse'
  R_SQUARED_COEFFICIENT_OF_DETERMINATION = 'r^2'

class abacusai.api_class.RegressionTreeHPOMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.PartialDependenceAnalysis

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.RegressionAugmentationStrategy

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SMOTE = 'smote'
  RESAMPLE = 'resample'

class abacusai.api_class.RegressionTargetTransform

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG = 'log'
  QUANTILE = 'quantile'
  YEO_JOHNSON = 'yeo-johnson'
  BOX_COX = 'box-cox'

class abacusai.api_class.RegressionTypeOfSplit

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RANDOM = 'Random Sampling'
  TIMESTAMP_BASED = 'Timestamp Based'
  ROW_INDICATOR_BASED = 'Row Indicator Based'

class abacusai.api_class.RegressionTimeSplitMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  TEST_SPLIT_PERCENTAGE_BASED = 'Test Split Percentage Based'
  TEST_START_TIMESTAMP_BASED = 'Test Start Timestamp Based'

class abacusai.api_class.RegressionLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HUBER = 'Huber'
  MSE = 'Mean Squared Error'
  MAE = 'Mean Absolute Error'
  MAPE = 'Mean Absolute Percentage Error'
  MSLE = 'Mean Squared Logarithmic Error'
  TWEEDIE = 'Tweedie'
  CROSS_ENTROPY = 'Cross Entropy'
  FOCAL_CROSS_ENTROPY = 'Focal Cross Entropy'
  AUTOMATIC = 'Automatic'
  CUSTOM = 'Custom'

class abacusai.api_class.ExplainerType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KERNEL_EXPLAINER = 'KERNEL_EXPLAINER'
  LIME_EXPLAINER = 'LIME_EXPLAINER'
  TREE_EXPLAINER = 'TREE_EXPLAINER'
  EBM_EXPLAINER = 'EBM_EXPLAINER'

class abacusai.api_class.SamplingMethodType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  N_SAMPLING = 'N_SAMPLING'
  PERCENT_SAMPLING = 'PERCENT_SAMPLING'

class abacusai.api_class.MergeMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LAST_N = 'LAST_N'
  TIME_WINDOW = 'TIME_WINDOW'

class abacusai.api_class.FillLogic

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVERAGE = 'average'
  MAX = 'max'
  MEDIAN = 'median'
  MIN = 'min'
  CUSTOM = 'custom'
  BACKFILL = 'bfill'
  FORWARDFILL = 'ffill'
  LINEAR = 'linear'
  NEAREST = 'nearest'

class abacusai.api_class.BatchSize

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BATCH_8 = 8
  BATCH_16 = 16
  BATCH_32 = 32
  BATCH_64 = 64
  BATCH_128 = 128
  BATCH_256 = 256
  BATCH_384 = 384
  BATCH_512 = 512
  BATCH_740 = 740
  BATCH_1024 = 1024

class abacusai.api_class.HolidayCalendars

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AU = 'AU'
  UK = 'UK'
  US = 'US'

class abacusai.api_class.FileFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVRO = 'AVRO'
  PARQUET = 'PARQUET'
  TFRECORD = 'TFRECORD'
  TSV = 'TSV'
  CSV = 'CSV'
  ORC = 'ORC'
  JSON = 'JSON'
  ODS = 'ODS'
  XLS = 'XLS'
  GZ = 'GZ'
  ZIP = 'ZIP'
  TAR = 'TAR'
  DOCX = 'DOCX'
  PDF = 'PDF'
  RAR = 'RAR'
  JPEG = 'JPG'
  PNG = 'PNG'
  TIF = 'TIFF'
  NUMBERS = 'NUMBERS'
  PPTX = 'PPTX'
  PPT = 'PPT'
  HTML = 'HTML'

class abacusai.api_class.ExperimentationMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.PersonalizationTrainingMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EXPERIMENTAL = 'EXP'
  PRODUCTION = 'PROD'

class abacusai.api_class.PersonalizationObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NDCG = 'ndcg'
  NDCG_5 = 'ndcg@5'
  NDCG_10 = 'ndcg@10'
  MAP = 'map'
  MAP_5 = 'map@5'
  MAP_10 = 'map@10'
  MRR = 'mrr'
  PERSONALIZATION = 'personalization@10'
  COVERAGE = 'coverage'

class abacusai.api_class.ForecastingObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY = 'w_c_accuracy'
  WAPE = 'wape'
  MAPE = 'mape'
  CMAPE = 'cmape'
  RMSE = 'rmse'
  CV = 'coefficient_of_variation'
  BIAS = 'bias'
  SRMSE = 'srmse'

class abacusai.api_class.ForecastingFrequency

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HOURLY = '1H'
  DAILY = '1D'
  WEEKLY_SUNDAY_START = '1W'
  WEEKLY_MONDAY_START = 'W-MON'
  WEEKLY_SATURDAY_START = 'W-SAT'
  MONTH_START = 'MS'
  MONTH_END = '1M'
  QUARTER_START = 'QS'
  QUARTER_END = '1Q'
  YEARLY = '1Y'

class abacusai.api_class.ForecastingDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Timestamp Based'
  ITEM = 'Item Based'
  PREDICTION_LENGTH = 'Force Prediction Length'

class abacusai.api_class.ForecastingLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CUSTOM = 'Custom'
  MEAN_ABSOLUTE_ERROR = 'mae'
  NORMALIZED_MEAN_ABSOLUTE_ERROR = 'nmae'
  PEAKS_MEAN_ABSOLUTE_ERROR = 'peaks_mae'
  MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_mape'
  POINTWISE_ACCURACY = 'accuracy'
  ROOT_MEAN_SQUARE_ERROR = 'rmse'
  NORMALIZED_ROOT_MEAN_SQUARE_ERROR = 'nrmse'
  ASYMMETRIC_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'asymmetric_mape'
  STABLE_STANDARDIZED_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_standardized_mape_with_cmape'
  GAUSSIAN = 'mle_gaussian_local'
  GAUSSIAN_FULL_COVARIANCE = 'mle_gaussfullcov'
  GUASSIAN_EXPONENTIAL = 'mle_gaussexp'
  MIX_GAUSSIANS = 'mle_gaussmix'
  WEIBULL = 'mle_weibull'
  NEGATIVE_BINOMIAL = 'mle_negbinom'
  LOG_ROOT_MEAN_SQUARE_ERROR = 'log_rmse'

class abacusai.api_class.ForecastingLocalScaling

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ZSCORE = 'zscore'
  SLIDING_ZSCORE = 'sliding_zscore'
  LAST_POINT = 'lastpoint'
  MIN_MAX = 'minmax'
  MIN_STD = 'minstd'
  ROBUST = 'robust'
  ITEM = 'item'

class abacusai.api_class.ForecastingFillMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BACK = 'BACK'
  MIDDLE = 'MIDDLE'
  FUTURE = 'FUTURE'

class abacusai.api_class.ForecastingQuanitlesExtensionMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DIRECT = 'direct'
  QUADRATIC = 'quadratic'
  ANCESTRAL_SIMULATION = 'simulation'

class abacusai.api_class.TimeseriesAnomalyDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Fixed Timestamp Based'

class abacusai.api_class.TimeseriesAnomalyTypeOfAnomaly

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HIGH_PEAK = 'high_peak'
  LOW_PEAK = 'low_peak'

class abacusai.api_class.NERObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG_LOSS = 'log_loss'
  AUC = 'auc'
  PRECISION = 'precision'
  RECALL = 'recall'
  ANNOTATIONS_PRECISION = 'annotations_precision'
  ANNOTATIONS_RECALL = 'annotations_recall'

class abacusai.api_class.NERModelType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  PRETRAINED_BERT = 'pretrained_bert'
  PRETRAINED_ROBERTA_27 = 'pretrained_roberta_27'
  PRETRAINED_ROBERTA_43 = 'pretrained_roberta_43'
  PRETRAINED_MULTILINGUAL = 'pretrained_multilingual'
  LEARNED = 'learned'

class abacusai.api_class.NLPDocumentFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'auto'
  TEXT = 'text'
  DOC = 'doc'
  TOKENS = 'tokens'

class abacusai.api_class.SentimentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  VALENCE = 'valence'
  EMOTION = 'emotion'

class abacusai.api_class.ClusteringImputationMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTOMATIC = 'Automatic'
  ZEROS = 'Zeros'
  INTERPOLATE = 'Interpolate'

class abacusai.api_class.ConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FILE = 'FILE'
  DATABASE = 'DATABASE'
  STREAMING = 'STREAMING'
  APPLICATION = 'APPLICATION'

class abacusai.api_class.ApplicationConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  GOOGLEANALYTICS = 'GOOGLEANALYTICS'
  GOOGLEDRIVE = 'GOOGLEDRIVE'
  GIT = 'GIT'
  CONFLUENCE = 'CONFLUENCE'
  JIRA = 'JIRA'
  ONEDRIVE = 'ONEDRIVE'
  ZENDESK = 'ZENDESK'
  SLACK = 'SLACK'
  SHAREPOINT = 'SHAREPOINT'
  TEAMS = 'TEAMS'
  ABACUSUSAGEMETRICS = 'ABACUSUSAGEMETRICS'
  MICROSOFTAUTH = 'MICROSOFTAUTH'

class abacusai.api_class.PythonFunctionArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  INTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'

class abacusai.api_class.PythonFunctionOutputArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'
  ANY = 'ANY'

class abacusai.api_class.VectorStoreTextEncoder

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  E5 = 'E5'
  OPENAI = 'OPENAI'
  SENTENCE_BERT = 'SENTENCE_BERT'
  E5_SMALL = 'E5_SMALL'

class abacusai.api_class.LLMName

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  OPENAI_GPT4 = 'OPENAI_GPT4'
  OPENAI_GPT4_32K = 'OPENAI_GPT4_32K'
  OPENAI_GPT4_128K = 'OPENAI_GPT4_128K'
  OPENAI_GPT3_5 = 'OPENAI_GPT3_5'
  OPENAI_GPT3_5_TEXT = 'OPENAI_GPT3_5_TEXT'
  CLAUDE_V2_1 = 'CLAUDE_V2_1'
  ABACUS_GIRAFFE = 'ABACUS_GIRAFFE'
  ABACUS_GIRAFFE_LARGE = 'ABACUS_GIRAFFE_LARGE'
  ABACUS_LLAMA2_QA = 'ABACUS_LLAMA2_QA'
  LLAMA2_CHAT = 'LLAMA2_CHAT'
  PALM = 'PALM'
  PALM_TEXT = 'PALM_TEXT'
  GEMINI_PRO = 'GEMINI_PRO'
  MIXTRAL_CHAT = 'MIXTRAL_CHAT'
  MISTRAL_MEDIUM = 'MISTRAL_MEDIUM'

class abacusai.api_class.MonitorAlertType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY_BELOW_THRESHOLD = 'AccuracyBelowThreshold'
  FEATURE_DRIFT = 'FeatureDrift'
  DATA_INTEGRITY_VIOLATIONS = 'DataIntegrityViolations'
  BIAS_VIOLATIONS = 'BiasViolations'
  HISTORY_LENGTH_DRIFT = 'HistoryLengthDrift'
  TARGET_DRIFT = 'TargetDrift'
  PREDICTION_COUNT = 'PredictionCount'

class abacusai.api_class.FeatureDriftType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KL = 'kl'
  KS = 'ks'
  WS = 'ws'
  JS = 'js'
  PSI = 'psi'
  CHI_SQUARE = 'chi_square'
  CSI = 'csi'

class abacusai.api_class.DataIntegrityViolationType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NULL_VIOLATIONS = 'null_violations'
  TYPE_MISMATCH_VIOLATIONS = 'type_mismatch_violations'
  RANGE_VIOLATIONS = 'range_violations'
  CATEGORICAL_RANGE_VIOLATION = 'categorical_range_violations'
  TOTAL_VIOLATIONS = 'total_violations'

class abacusai.api_class.BiasType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEMOGRAPHIC_PARITY = 'demographic_parity'
  EQUAL_OPPORTUNITY = 'equal_opportunity'
  GROUP_BENEFIT_EQUALITY = 'group_benefit'
  TOTAL = 'total'

class abacusai.api_class.AlertActionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EMAIL = 'Email'

class abacusai.api_class.PythonFunctionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  PLOTLY_FIG = 'PLOTLY_FIG'
  STEP_FUNCTION = 'STEP_FUNCTION'

class abacusai.api_class.EvalArtifactType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FORECASTING_ACCURACY = 'bar_chart'
  FORECASTING_VOLUME = 'bar_chart_volume'
  FORECASTING_HISTORY_LENGTH_ACCURACY = 'bar_chart_accuracy_by_history'

class abacusai.api_class.FieldDescriptorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  STRING = 'STRING'
  INTEGER = 'INTEGER'
  FLOAT = 'FLOAT'
  BOOLEAN = 'BOOLEAN'
  DATETIME = 'DATETIME'
  DATE = 'DATE'

class abacusai.api_class.OcrMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEFAULT = 'DEFAULT'
  LAYOUT = 'LAYOUT'
  SCANNED = 'SCANNED'
  COMPREHENSIVE = 'COMPREHENSIVE'
  COMPREHENSIVE_V2 = 'COMPREHENSIVE_V2'
  COMPREHENSIVE_TABLE_MD = 'COMPREHENSIVE_TABLE_MD'

class abacusai.api_class.DataType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  INTEGER = 'integer'
  FLOAT = 'float'
  STRING = 'string'
  DATE = 'date'
  DATETIME = 'datetime'
  BOOLEAN = 'boolean'
  LIST = 'list'
  STRUCT = 'struct'
  NULL = 'null'
  classmethod from_str(value)

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.SamplingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for the sampling config of a feature group

  sampling_method: abacusai.api_class.enums.SamplingMethodType
  classmethod _get_builder()
  __post_init__()

class abacusai.api_class.NSamplingConfig

  Bases: `SamplingConfig`

  The number of distinct values of the key columns to include in the sample, or number of rows if key columns not specified.

  Parameters:

    - sampling_method (SamplingMethodType) – N_SAMPLING

    - sample_count (int) – The number of rows to include in the sample

    - key_columns (List[str]) – The feature(s) to use as the key(s) when sampling

  sample_count: int
  key_columns: List[str]
  __post_init__()

class abacusai.api_class.PercentSamplingConfig

  Bases: `SamplingConfig`

  The fraction of distinct values of the feature group to include in the sample.

  Parameters:

    - sampling_method (SamplingMethodType) – PERCENT_SAMPLING

    - sample_percent (float) – The percentage of the rows to sample

    - key_columns (List[str]) – The feature(s) to use as the key(s) when sampling

  sample_percent: float
  key_columns: List[str]
  __post_init__()

class abacusai.api_class._SamplingConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_class_key = 'sampling_method'
  config_abstract_class
  config_class_map

class abacusai.api_class.MergeConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for the merge config of a feature group

  merge_mode: abacusai.api_class.enums.MergeMode
  classmethod _get_builder()
  __post_init__()

class abacusai.api_class.LastNMergeConfig

  Bases: `MergeConfig`

  Merge LAST N chunks/versions of an incremental dataset.

  Parameters:

    - merge_mode (MergeMode) – LAST_N

    - num_versions (int) – The number of versions to merge. num_versions == 0 means merge all versions.

    - include_version_timestamp_column (bool) – If set, include a column with the creation timestamp of source FG versions.

  num_versions: int
  include_version_timestamp_column: bool
  __post_init__()

class abacusai.api_class.TimeWindowMergeConfig

  Bases: `MergeConfig`

  Merge rows within a given timewindow of the most recent timestamp

  Parameters:

    - merge_mode (MergeMode) – TIME_WINDOW

    - feature_name (str) – Time based column to index on

    - time_window_size_ms (int) – Range of merged rows will be [MAX_TIME - time_window_size_ms, MAX_TIME]

    - include_version_timestamp_column (bool) – If set, include a column with the creation timestamp of source FG versions.

  feature_name: str
  time_window_size_ms: int
  include_version_timestamp_column: bool
  __post_init__()

class abacusai.api_class._MergeConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_class_key = 'merge_mode'
  config_abstract_class
  config_class_map

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.TrainingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  kwargs: dict
  problem_type: abacusai.api_class.enums.ProblemType
  algorithm: str
  classmethod _get_builder()

class abacusai.api_class.PersonalizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the PERSONALIZATION problem type

  Parameters:

    - objective (PersonalizationObjective) – Ranking scheme used to select final best model.

    - sort_objective (PersonalizationObjective) – Ranking scheme used to sort models on the metrics page.

    - training_mode (PersonalizationTrainingMode) – whether to train in production or experimental mode. Defaults to EXP.

    - target_action_types (List[str]) – List of action types to use as targets for training.

    - target_action_weights (Dict[str, float]) – Dictionary of action types to weights for training.

    - session_event_types (List[str]) – List of event types to treat as occurrences of sessions.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 6% to 20% of your dataset to use as test data.

    - recent_days_for_training (int) – Limit training data to a certain latest number of days.

    - training_start_date (str) – Only consider training interaction data after this date. Specified in the timezone of the dataset.

    - test_on_user_split (bool) – Use user splits instead of using time splits, when validating and testing the model.

    - test_split_on_last_k_items (bool) – Use last k items instead of global timestamp splits, when validating and testing the model.

    - test_last_items_length (int) – Number of items to leave out for each user when using leave k out folds.

    - test_window_length_hours (int) – Duration (in hours) of most recent time window to use when validating and testing the model.

    - explicit_time_split (bool) – Sets an explicit time-based test boundary.

    - test_row_indicator (str) – Column indicating which rows to use for training (TRAIN), validation (VAL) and testing (TEST).

    - full_data_retraining (bool) – Train models separately with all the data.

    - sequential_training (bool) – Train a mode sequentially through time.

    - data_split_feature_group_table_name (str) – Specify the table name of the feature group to export training data with the fold column.

    - optimized_event_type (str) – The final event type to optimize for and compute metrics on.

    - dropout_rate (int) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

    - disable_transformer (bool) – Disable training the transformer algorithm.

    - disable_gpu (boo) – Disable training on GPU.

    - filter_history (bool) – Do not recommend items the user has already interacted with.

    - action_types_exclusion_days (Dict[str, float]) – Mapping from action type to number of days for which we exclude previously interacted items from prediction

    - session_dedupe_mins (float) – Minimum number of minutes between two sessions for a user.

    - max_history_length (int) – Maximum length of user-item history to include user in training examples.

    - compute_rerank_metrics (bool) – Compute metrics based on rerank results.

    - add_time_features (bool) – Include interaction time as a feature.

    - disable_timestamp_scalar_features (bool) – Exclude timestamp scalar features.

    - compute_session_metrics (bool) – Evaluate models based on how well they are able to predict the next session of interactions.

    - max_user_history_len_percentile (int) – Filter out users with history length above this percentile.

    - downsample_item_popularity_percentile (float) – Downsample items more popular than this percentile.

    - use_user_id_feature (bool) – Use user id as a feature in CTR models.

    - min_item_history (int) – Minimum number of interactions an item must have to be included in training.

  objective: abacusai.api_class.enums.PersonalizationObjective
  sort_objective: abacusai.api_class.enums.PersonalizationObjective
  training_mode: abacusai.api_class.enums.PersonalizationTrainingMode
  target_action_types: List[str]
  target_action_weights: Dict[str, float]
  session_event_types: List[str]
  test_split: int
  recent_days_for_training: int
  training_start_date: str
  test_on_user_split: bool
  test_split_on_last_k_items: bool
  test_last_items_length: int
  test_window_length_hours: int
  explicit_time_split: bool
  test_row_indicator: str
  full_data_retraining: bool
  sequential_training: bool
  data_split_feature_group_table_name: str
  optimized_event_type: str
  dropout_rate: int
  batch_size: abacusai.api_class.enums.BatchSize
  disable_transformer: bool
  disable_gpu: bool
  filter_history: bool
  action_types_exclusion_days: Dict[str, float]
  max_history_length: int
  compute_rerank_metrics: bool
  add_time_features: bool
  disable_timestamp_scalar_features: bool
  compute_session_metrics: bool
  query_column: str
  item_query_column: str
  use_user_id_feature: bool
  session_dedupe_mins: float
  max_user_history_len_percentile: int
  downsample_item_popularity_percentile: float
  min_item_history: int
  __post_init__()

class abacusai.api_class.RegressionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the PREDICTIVE_MODELING problem type

  Parameters:

    - objective (RegressionObjective) – Ranking scheme used to select final best model.

    - sort_objective (RegressionObjective) – Ranking scheme used to sort models on the metrics page.

    - tree_hpo_mode – (RegressionTreeHPOMode): Turning off Rapid Experimentation will take longer to train.

    - type_of_split (RegressionTypeOfSplit) – Type of data splitting into train/test (validation also).

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5% to 20% of your dataset to use as test data.

    - disable_test_val_fold (bool) – Do not create a TEST_VAL set. All records which would be part of the TEST_VAL fold otherwise, remain in the TEST fold.

    - k_fold_cross_validation (bool) – Use this to force k-fold cross validation bagging on or off.

    - num_cv_folds (int) – Specify the value of k in k-fold cross validation.

    - timestamp_based_splitting_column (str) – Timestamp column selected for splitting into test and train.

    - timestamp_based_splitting_method (RegressionTimeSplitMethod) – Method of selecting TEST set, top percentile wise or after a given timestamp.

    - test_splitting_timestamp (str) – Rows with timestamp greater than this will be considered to be in the test set.

    - sampling_unit_keys (List[str]) – Constrain train/test separation to partition a column.

    - test_row_indicator (str) – Column indicating which rows to use for training (TRAIN) and testing (TEST). Validation (VAL) can also be specified.

    - full_data_retraining (bool) – Train models separately with all the data.

    - rebalance_classes (bool) – Class weights are computed as the inverse of the class frequency from the training dataset when this option is selected as “Yes”. It is useful when the classes in the dataset are unbalanced. Re-balancing classes generally boosts recall at the cost of precision on rare classes.

    - rare_class_augmentation_threshold (float) – Augments any rare class whose relative frequency with respect to the most frequent class is less than this threshold. Default = 0.1 for classification problems with rare classes.

    - augmentation_strategy (RegressionAugmentationStrategy) – Strategy to deal with class imbalance and data augmentation.

    - training_rows_downsample_ratio (float) – Uses this ratio to train on a sample of the dataset provided.

    - active_labels_column (str) – Specify a column to use as the active columns in a multi label setting.

    - min_categorical_count (int) – Minimum threshold to consider a value different from the unknown placeholder.

    - sample_weight (str) – Specify a column to use as the weight of a sample for training and eval.

    - numeric_clipping_percentile (float) – Uses this option to clip the top and bottom x percentile of numeric feature columns where x is the value of this option.

    - target_transform (RegressionTargetTransform) – Specify a transform (e.g. log, quantile) to apply to the target variable.

    - ignore_datetime_features (bool) – Remove all datetime features from the model. Useful while generalizing to different time periods.

    - max_text_words (int) – Maximum number of words to use from text fields.

    - perform_feature_selection (bool) – If enabled, additional algorithms which support feature selection as a pretraining step will be trained separately with the selected subset of features. The details about their selected features can be found in their respective logs.

    - feature_selection_intensity (int) – This determines the strictness with which features will be filtered out. 1 being very lenient (more features kept), 100 being very strict.

    - batch_size (BatchSize) – Batch size.

    - dropout_rate (int) – Dropout percentage rate.

    - pretrained_model_name (str) – Enable algorithms which process text using pretrained multilingual NLP models.

    - is_multilingual (bool) – Enable algorithms which process text using pretrained multilingual NLP models.

    - loss_function (RegressionLossFunction) – Loss function to be used as objective for model training.

    - loss_parameters (str) – Loss function params in format <key>=<value>;<key>=<value>;…..

    - target_encode_categoricals (bool) – Use this to turn target encoding on categorical features on or off.

    - drop_original_categoricals (bool) – This option helps us choose whether to also feed the original label encoded categorical columns to the mdoels along with their target encoded versions.

    - monotonically_increasing_features (List[str]) – Constrain the model such that it behaves as if the target feature is monotonically increasing with the selected features

    - monotonically_decreasing_features (List[str]) – Constrain the model such that it behaves as if the target feature is monotonically decreasing with the selected features

    - data_split_feature_group_table_name (str) – Specify the table name of the feature group to export training data with the fold column.

    - custom_loss_functions (List[str]) – Registered custom losses available for selection.

    - custom_metrics (List[str]) – Registered custom metrics available for selection.

    - partial_dependence_analysis (PartialDependenceAnalysis) – Specify whether to run partial dependence plots for all features or only some features.

  objective: abacusai.api_class.enums.RegressionObjective
  sort_objective: abacusai.api_class.enums.RegressionObjective
  tree_hpo_mode: abacusai.api_class.enums.RegressionTreeHPOMode
  partial_dependence_analysis: abacusai.api_class.enums.PartialDependenceAnalysis
  type_of_split: abacusai.api_class.enums.RegressionTypeOfSplit
  test_split: int
  disable_test_val_fold: bool
  k_fold_cross_validation: bool
  num_cv_folds: int
  timestamp_based_splitting_column: str
  timestamp_based_splitting_method: abacusai.api_class.enums.RegressionTimeSplitMethod
  test_splitting_timestamp: str
  sampling_unit_keys: List[str]
  test_row_indicator: str
  full_data_retraining: bool
  rebalance_classes: bool
  rare_class_augmentation_threshold: float
  augmentation_strategy: abacusai.api_class.enums.RegressionAugmentationStrategy
  training_rows_downsample_ratio: float
  active_labels_column: str
  min_categorical_count: int
  sample_weight: str
  numeric_clipping_percentile: float
  target_transform: abacusai.api_class.enums.RegressionTargetTransform
  ignore_datetime_features: bool
  max_text_words: int
  perform_feature_selection: bool
  feature_selection_intensity: int
  batch_size: abacusai.api_class.enums.BatchSize
  dropout_rate: int
  pretrained_model_name: str
  is_multilingual: bool
  loss_function: abacusai.api_class.enums.RegressionLossFunction
  loss_parameters: str
  target_encode_categoricals: bool
  drop_original_categoricals: bool
  monotonically_increasing_features: List[str]
  monotonically_decreasing_features: List[str]
  data_split_feature_group_table_name: str
  custom_loss_functions: List[str]
  custom_metrics: List[str]
  __post_init__()

class abacusai.api_class.ForecastingTrainingConfig

  Bases: `TrainingConfig`

  Training config for the FORECASTING problem type

  Parameters:

    - prediction_length (int) – How many timesteps in the future to predict.

    - objective (ForecastingObjective) – Ranking scheme used to select final best model.

    - sort_objective (ForecastingObjective) – Ranking scheme used to sort models on the metrics page.

    - forecast_frequency (ForecastingFrequency) – Forecast frequency.

    - probability_quantiles (List[float]) – Prediction quantiles.

    - force_prediction_length (int) – Force length of test window to be the same as prediction length.

    - filter_items (bool) – Filter items with small history and volume.

    - enable_feature_selection (bool) – Enable feature selection.

    - enable_padding (bool) – Pad series to the max_date of the dataset

    - enable_cold_start (bool) – Enable cold start forecasting by training/predicting for zero history items.

    - enable_multiple_backtests (bool) – Whether to enable multiple backtesting or not.

    - num_backtesting_windows (int) – Total backtesting windows to use for the training.

    - backtesting_window_step_size (int) – Use this step size to shift backtesting windows for model training.

    - full_data_retraining (bool) – Train models separately with all the data.

    - additional_forecast_keys – List[str]: List of categoricals in timeseries that can act as multi-identifier.

    - experimentation_mode (ExperimentationMode) – Selecting Thorough Experimentation will take longer to train.

    - type_of_split (ForecastingDataSplitType) – Type of data splitting into train/test.

    - test_by_item (bool) – Partition train/test data by item rather than time if true.

    - test_start (str) – Limit training data to dates before the given test start.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5% to 20% of your dataset to use as test data.

    - loss_function (ForecastingLossFunction) – Loss function for training neural network.

    - underprediction_weight (float) – Weight for underpredictions

    - disable_networks_without_analytic_quantiles (bool) – Disable neural networks, which quantile functions do not have analytic expressions (e.g, mixture models)

    - initial_learning_rate (float) – Initial learning rate.

    - l2_regularization_factor (float) – L2 regularization factor.

    - dropout_rate (int) – Dropout percentage rate.

    - recurrent_layers (int) – Number of recurrent layers to stack in network.

    - recurrent_units (int) – Number of units in each recurrent layer.

    - convolutional_layers (int) – Number of convolutional layers to stack on top of recurrent layers in network.

    - convolution_filters (int) – Number of filters in each convolution.

    - local_scaling_mode (ForecastingLocalScaling) – Options to make NN inputs stationary in high dynamic range datasets.

    - zero_predictor (bool) – Include subnetwork to classify points where target equals zero.

    - skip_missing (bool) – Make the RNN ignore missing entries rather instead of processing them.

    - batch_size (ForecastingBatchSize) – Batch size.

    - batch_renormalization (bool) – Enable batch renormalization between layers.

    - history_length (int) – While training, how much history to consider.

    - prediction_step_size (int) – Number of future periods to include in objective for each training sample.

    - training_point_overlap (float) – Amount of overlap to allow between training samples.

    - max_scale_context (int) – Maximum context to use for local scaling.

    - quantiles_extension_method (ForecastingQuanitlesExtensionMethod) – Quantile extension method

    - number_of_samples (int) – Number of samples for ancestral simulation

    - symmetrize_quantiles (bool) – Force symmetric quantiles (like in Gaussian distribution)

    - use_log_transforms (bool) – Apply logarithmic transformations to input data.

    - smooth_history (float) – Smooth (low pass filter) the timeseries.

    - local_scale_target (bool) – Using per training/prediction window target scaling.

    - use_clipping (bool) – Apply clipping to input data to stabilize the training.

    - timeseries_weight_column (str) – If set, we use the values in this column from timeseries data to assign time dependent item weights during training and evaluation.

    - item_attributes_weight_column (str) – If set, we use the values in this column from item attributes data to assign weights to items during training and evaluation.

    - use_timeseries_weights_in_objective (bool) – If True, we include weights from column set as “TIMESERIES WEIGHT COLUMN” in objective functions.

    - use_item_weights_in_objective (bool) – If True, we include weights from column set as “ITEM ATTRIBUTES WEIGHT COLUMN” in objective functions.

    - skip_timeseries_weight_scaling (bool) – If True, we will avoid normalizing the weights.

    - timeseries_loss_weight_column (str) – Use value in this column to weight the loss while training.

    - use_item_id (bool) – Include a feature to indicate the item being forecast.

    - use_all_item_totals (bool) – Include as input total target across items.

    - handle_zeros_as_missing_values (bool) – If True, handle zero values in demand as missing data.

    - datetime_holiday_calendars (List[HolidayCalendars]) – Holiday calendars to augment training with.

    - fill_missing_values (List[dict]) – Strategy for filling in missing values.

    - enable_clustering (bool) – Enable clustering in forecasting.

    - data_split_feature_group_table_name (str) – Specify the table name of the feature group to export training data with the fold column.

    - custom_loss_functions (List[str]) – Registered custom losses available for selection.

    - custom_metrics (List[str]) – Registered custom metrics available for selection.

    - return_fractional_forecasts – Use this to return fractional forecast values while prediction

  prediction_length: int
  objective: abacusai.api_class.enums.ForecastingObjective
  sort_objective: abacusai.api_class.enums.ForecastingObjective
  forecast_frequency: abacusai.api_class.enums.ForecastingFrequency
  probability_quantiles: List[float]
  force_prediction_length: bool
  filter_items: bool
  enable_feature_selection: bool
  enable_padding: bool
  enable_cold_start: bool
  enable_multiple_backtests: bool
  num_backtesting_windows: int
  backtesting_window_step_size: int
  full_data_retraining: bool
  additional_forecast_keys: List[str]
  experimentation_mode: abacusai.api_class.enums.ExperimentationMode
  type_of_split: abacusai.api_class.enums.ForecastingDataSplitType
  test_by_item: bool
  test_start: str
  test_split: int
  loss_function: abacusai.api_class.enums.ForecastingLossFunction
  underprediction_weight: float
  disable_networks_without_analytic_quantiles: bool
  initial_learning_rate: float
  l2_regularization_factor: float
  dropout_rate: int
  recurrent_layers: int
  recurrent_units: int
  convolutional_layers: int
  convolution_filters: int
  local_scaling_mode: abacusai.api_class.enums.ForecastingLocalScaling
  zero_predictor: bool
  skip_missing: bool
  batch_size: abacusai.api_class.enums.BatchSize
  batch_renormalization: bool
  history_length: int
  prediction_step_size: int
  training_point_overlap: float
  max_scale_context: int
  quantiles_extension_method: abacusai.api_class.enums.ForecastingQuanitlesExtensionMethod
  number_of_samples: int
  symmetrize_quantiles: bool
  use_log_transforms: bool
  smooth_history: float
  local_scale_target: bool
  use_clipping: bool
  timeseries_weight_column: str
  item_attributes_weight_column: str
  use_timeseries_weights_in_objective: bool
  use_item_weights_in_objective: bool
  skip_timeseries_weight_scaling: bool
  timeseries_loss_weight_column: str
  use_item_id: bool
  use_all_item_totals: bool
  handle_zeros_as_missing_values: bool
  datetime_holiday_calendars: List[abacusai.api_class.enums.HolidayCalendars]
  fill_missing_values: List[dict]
  enable_clustering: bool
  data_split_feature_group_table_name: str
  custom_loss_functions: List[str]
  custom_metrics: List[str]
  return_fractional_forecasts: bool
  __post_init__()

class abacusai.api_class.NamedEntityExtractionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the NAMED_ENTITY_EXTRACTION problem type

  Parameters:

    - objective (NERObjective) – Ranking scheme used to select final best model.

    - sort_objective (NERObjective) – Ranking scheme used to sort models on the metrics page.

    - ner_model_type (NERModelType) – Type of NER model to use.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - test_row_indicator (str) – Column indicating which rows to use for training (TRAIN) and testing (TEST).

    - active_labels_column (str) – Entities that have been marked in a particular text

    - document_format (NLPDocumentFormat) – Format of the input documents.

    - include_longformer (bool) – Whether to include the longformer model.

    - minimum_bounding_box_overlap_ratio (float) – Tokens are considered to belong to annotation if the user bounding box is provided and ratio of (token_bounding_box ∩ annotation_bounding_box) / token_bounding_area is greater than the provided value.

    - save_predicted_pdf (bool) – Whether to save predicted PDF documents

    - enhanced_ocr (bool) – Enhanced text extraction from predicted digital documents

  objective: abacusai.api_class.enums.NERObjective
  sort_objective: abacusai.api_class.enums.NERObjective
  ner_model_type: abacusai.api_class.enums.NERModelType
  test_split: int
  test_row_indicator: str
  active_labels_column: str
  document_format: abacusai.api_class.enums.NLPDocumentFormat
  include_longformer: bool
  minimum_bounding_box_overlap_ratio: float = 0.0
  save_predicted_pdf: bool = True
  enhanced_ocr: bool = False
  __post_init__()

class abacusai.api_class.NaturalLanguageSearchTrainingConfig

  Bases: `TrainingConfig`

  Training config for the NATURAL_LANGUAGE_SEARCH problem type

  Parameters:

    - abacus_internal_model (bool) – Use a Abacus.AI LLM to answer questions about your data without using any external APIs

    - num_completion_tokens (int) – Default for maximum number of tokens for chat answers. Reducing this will get faster responses which are more succinct

    - larger_embeddings (bool) – Use a higher dimension embedding model.

    - search_chunk_size (int) – Chunk size for indexing the documents.

    - chunk_overlap_fraction (float) – Overlap in chunks while indexing the documents.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

  abacus_internal_model: bool
  num_completion_tokens: int
  larger_embeddings: bool
  search_chunk_size: int
  index_fraction: float
  chunk_overlap_fraction: float
  __post_init__()

class abacusai.api_class.ChatLLMTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CHAT_LLM problem type

  Parameters:

    - document_retrievers (List[str]) – List of document retriever names to use for the feature stores this model was trained with.

    - num_completion_tokens (int) – Default for maximum number of tokens for chat answers. Reducing this will get faster responses which are more succinct

    - temperature (float) – The generative LLM temperature

    - metadata_columns (list) – Include the metadata column values in the retrieved search results.

    - include_general_knowledge (bool) – Allow the LLM to rely not just on search results, but to fall back on general knowledge.

    - behavior_instructions (str) – Customize the overall role instructions for the LLM.

    - response_instructions (str) – Customize instructions for what the LLM responses should look like.

    - lookup_rewrite_instructions (str) – Instructions for a LLM call to automatically generate filter expressions on document metadata to retrieve relevant documents for the conversation.

    - max_search_results (int) – Maximum number of search results in the retrieval augmentation step. If we know that the questions are likely to have snippets which are easily matched in the documents, then a lower number will help with accuracy.

    - data_feature_group_ids – (List[str]): List of feature group ids to use to possibly query for the chatllm.

    - data_prompt_context (str) – Prompt context for the data feature group ids.

    - hide_generated_sql (bool) – When running data queries, hides the generated SQL in the response and will just return the table.

    - disable_data_summarization (bool) – After executing a query summarize the reponse and reply back with only the table and query run.

    - search_score_cutoff (float) – Minimum search score to consider a document as a valid search result.

    - database_connector_id (str) – Database connector id to use for the chatllm.

  document_retrievers: List[str]
  num_completion_tokens: int
  temperature: float
  metadata_columns: list
  include_general_knowledge: bool
  behavior_instructions: str
  response_instructions: str
  lookup_rewrite_instructions: str
  max_search_results: int
  data_feature_group_ids: List[str]
  data_prompt_context: str
  hide_generated_sql: bool
  disable_data_summarization: bool
  search_score_cutoff: float
  database_connector_id: str
  __post_init__()

class abacusai.api_class.SentenceBoundaryDetectionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the SENTENCE_BOUNDARY_DETECTION problem type

  Parameters:

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - dropout_rate (float) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.SentimentDetectionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the SENTIMENT_DETECTION problem type

  Parameters:

    - sentiment_type (SentimentType) – Type of sentiment to detect.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - dropout_rate (float) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

    - compute_metrics (bool) – Whether to compute metrics.

  sentiment_type: abacusai.api_class.enums.SentimentType
  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  compute_metrics: bool
  __post_init__()

class abacusai.api_class.DocumentClassificationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_CLASSIFICATION problem type

  Parameters:

    - zero_shot_hypotheses (List[str]) – Zero shot hypotheses. Example text: ‘This text is about pricing’.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - dropout_rate (float) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

  zero_shot_hypotheses: List[str]
  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.DocumentSummarizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_SUMMARIZATION problem type

  Parameters:

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - dropout_rate (float) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.DocumentVisualizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_VISUALIZATION problem type

  Parameters:

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - dropout_rate (float) – Dropout rate for neural network.

    - batch_size (BatchSize) – Batch size for neural network.

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.ClusteringTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CLUSTERING problem type

  Parameters:

    num_clusters_selection (int) – Number of clusters. If None, will be selected automatically.

  num_clusters_selection: int
  __post_init__()

class abacusai.api_class.ClusteringTimeseriesTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CLUSTERING_TIMESERIES problem type

  Parameters:

    - num_clusters_selection (int) – Number of clusters. If None, will be selected automatically.

    - imputation (ClusteringImputationMethod) – Imputation method for missing values.

  num_clusters_selection: int
  imputation: abacusai.api_class.enums.ClusteringImputationMethod
  __post_init__()

class abacusai.api_class.EventAnomalyTrainingConfig

  Bases: `TrainingConfig`

  Training config for the EVENT_ANOMALY problem type

  Parameters:

    anomaly_fraction (float) – The fraction of the dataset to classify as anomalous, between 0 and 0.5

  anomaly_fraction: float
  __post_init__()

class abacusai.api_class.TimeseriesAnomalyTrainingConfig

  Bases: `TrainingConfig`

  Training config for the TS_ANOMALY problem type

  Args: type_of_split (TimeseriesAnomalyDataSplitType): Type of data splitting into train/test. test_start (str): Limit training data to dates before the given test start. test_split (int): Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. fill_missing_values (List[dict]): strategies to fill missing values and missing timestamps handle_zeros_as_missing_values (bool): If True, handle zero values in numeric columns as missing data timeseries_frequency (str): set this to control frequency of filling missing values min_samples_in_normal_region (int): Adjust this to fine-tune the number of anomalies to be identified. anomaly_type (TimeseriesAnomalyTypeOfAnomaly): select what kind of peaks to detect as anomalies threshold_score (float): Threshold score for anomaly detection

  type_of_split: abacusai.api_class.enums.TimeseriesAnomalyDataSplitType
  test_start: str
  test_split: int
  fill_missing_values: List[dict]
  handle_zeros_as_missing_values: bool
  timeseries_frequency: str
  min_samples_in_normal_region: int
  anomaly_type: abacusai.api_class.enums.TimeseriesAnomalyTypeOfAnomaly
  threshold_score: float
  __post_init__()

class abacusai.api_class.CumulativeForecastingTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUMULATIVE_FORECASTING problem type

  Parameters:

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset.

    - historical_frequency (str) – Forecast frequency

    - cumulative_prediction_lengths (List[int]) – List of Cumulative Prediction Frequencies. Each prediction length must be between 1 and 365.

    - skip_input_transform (bool) – Avoid doing numeric scaling transformations on the input.

    - skip_target_transform (bool) – Avoid doing numeric scaling transformations on the target.

    - predict_residuals (bool) – Predict residuals instead of totals at each prediction step.

  test_split: int
  historical_frequency: str
  cumulative_prediction_lengths: List[int]
  skip_input_transform: bool
  skip_target_transform: bool
  predict_residuals: bool
  __post_init__()

class abacusai.api_class.ThemeAnalysisTrainingConfig

  Bases: `TrainingConfig`

  Training config for the THEME ANALYSIS problem type

  __post_init__()

class abacusai.api_class.AIAgentTrainingConfig

  Bases: `TrainingConfig`

  Training config for the AI_AGENT problem type

  Parameters:

    - description (str) – Description of the agent function.

    - enable_binary_input (bool) – If True, the agent will be able to accept binary data as inputs.

    - agent_input_schema (dict) – Schema for the agent input.

    - agent_output_schema (dict) – Schema for the agent output.

  description: str
  enable_binary_input: bool
  agent_input_schema: dict
  agent_output_schema: dict
  __post_init__()

class abacusai.api_class.CustomTrainedModelTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUSTOM_TRAINED_MODEL problem type

  Parameters:

    - max_catalog_size (int) – Maximum expected catalog size.

    - max_dimension (int) – Maximum expected dimension of the catalog.

    - index_output_path (str) – Fully qualified cloud location (GCS, S3, etc) to export snapshots of the embedding to.

    - docker_image_uri (str) – Docker image URI.

    - service_port (int) – Service port.

  max_catalog_size: int
  max_dimension: int
  index_output_path: str
  docker_image_uri: str
  service_port: int
  __post_init__()

class abacusai.api_class.CustomAlgorithmTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUSTOM_ALGORITHM problem type

  Parameters:

    - train_function_name (str) – The name of the train function.

    - predict_many_function_name (str) – The name of the predict many function.

    - training_input_tables (List[str]) – List of tables to use for training.

    - predict_function_name (str) – Optional name of the predict function if the predict many function is not given.

    - train_module_name (str) – The name of the train module - only relevant if model is being uploaded from a zip file or github repositoty.

    - predict_module_name (str) – The name of the predict module - only relevant if model is being uploaded from a zip file or github repositoty.

    - test_split (int) – Percent of dataset to use for test data. We support using a range between 6% to 20% of your dataset to use as test data.

  train_function_name: str
  predict_many_function_name: str
  training_input_tables: List[str]
  predict_function_name: str
  train_module_name: str
  predict_module_name: str
  test_split: int
  __post_init__()

class abacusai.api_class.OptimizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the OPTIMIZATION problem type

  Parameters:

    solve_time_limit (float) – The maximum time in seconds to spend solving the problem. Accepts values between 0 and 86400.

  solve_time_limit: float
  __post_init__()

class abacusai.api_class._TrainingConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'problem_type'
  config_class_map

class abacusai.api_class.DeployableAlgorithm

  Bases: `abacusai.api_class.abstract.ApiClass`

  Algorithm that can be deployed to a model.

  Parameters:

    - algorithm (str) – ID of the algorithm.

    - name (str) – Name of the algorithm.

    - only_offline_deployable (bool) – Whether the algorithm can only be deployed offline.

    - trained_model_types (List[dict]) – List of trained model types.

  algorithm: str
  name: str
  only_offline_deployable: bool
  trained_model_types: List[dict]

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.ForecastingMonitorConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  id_column: str
  timestamp_column: str
  target_column: str
  start_time: str
  end_time: str
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.AlertConditionConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  alert_type: abacusai.api_class.enums.MonitorAlertType
  classmethod _get_builder()

class abacusai.api_class.AccuracyBelowThresholdConditionConfig

  Bases: `AlertConditionConfig`

  Accuracy Below Threshold Condition Config for Monitor Alerts

  Parameters:

    threshold (float) – Threshold for when to consider a column to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

  threshold: float
  __post_init__()

class abacusai.api_class.FeatureDriftConditionConfig

  Bases: `AlertConditionConfig`

  Feature Drift Condition Config for Monitor Alerts

  Parameters:

    - feature_drift_type (FeatureDriftType) – Feature drift type to apply the threshold on to determine whether a column has drifted significantly enough to be a violation.

    - threshold (float) – Threshold for when to consider a column to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

    - minimum_violations (int) – Number of columns that must exceed the specified threshold to trigger an alert.

    - feature_names (List[str]) – List of feature names to monitor for this alert.

  feature_drift_type: abacusai.api_class.enums.FeatureDriftType
  threshold: float
  minimum_violations: int
  feature_names: List[str]
  __post_init__()

class abacusai.api_class.TargetDriftConditionConfig

  Bases: `AlertConditionConfig`

  Target Drift Condition Config for Monitor Alerts

  Parameters:

    - feature_drift_type (FeatureDriftType) – Target drift type to apply the threshold on to determine whether a column has drifted significantly enough to be a violation.

    - threshold (float) – Threshold for when to consider the target column to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

  feature_drift_type: abacusai.api_class.enums.FeatureDriftType
  threshold: float
  __post_init__()

class abacusai.api_class.HistoryLengthDriftConditionConfig

  Bases: `AlertConditionConfig`

  History Length Drift Condition Config for Monitor Alerts

  Parameters:

    - feature_drift_type (FeatureDriftType) – History length drift type to apply the threshold on to determine whether the history length has drifted significantly enough to be a violation.

    - threshold (float) – Threshold for when to consider the history length to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

  feature_drift_type: abacusai.api_class.enums.FeatureDriftType
  threshold: float
  __post_init__()

class abacusai.api_class.DataIntegrityViolationConditionConfig

  Bases: `AlertConditionConfig`

  Data Integrity Violation Condition Config for Monitor Alerts

  Parameters:

    - data_integrity_type (DataIntegrityViolationType) – This option selects the data integrity violations to monitor for this alert.

    - minimum_violations (int) – Number of columns that must exceed the specified threshold to trigger an alert.

  data_integrity_type: abacusai.api_class.enums.DataIntegrityViolationType
  minimum_violations: int
  __post_init__()

class abacusai.api_class.BiasViolationConditionConfig

  Bases: `AlertConditionConfig`

  Bias Violation Condition Config for Monitor Alerts

  Parameters:

    - bias_type (BiasType) – This option selects the bias metric to monitor for this alert.

    - threshold (float) – Threshold for when to consider a column to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

    - minimum_violations (int) – Number of columns that must exceed the specified threshold to trigger an alert.

  bias_type: abacusai.api_class.enums.BiasType
  threshold: float
  minimum_violations: int
  __post_init__()

class abacusai.api_class.PredictionCountConditionConfig

  Bases: `AlertConditionConfig`

  Deployment Prediction Condition Config for Deployment Alerts. By default we monitor if predictions made over a time window has reduced significantly. :param threshold: Threshold for when to consider to be a violation. Negative means alert on reduction, positive means alert on increase. :type threshold: float :param aggregation_window: Time window to aggregate the predictions over, e.g. 1h, 10m. Only h(hour), m(minute) and s(second) are supported. :type aggregation_window: str :param aggregation_type: Aggregation type to use for the aggregation window, e.g. sum, avg. :type aggregation_type: str

  threshold: float
  aggregation_window: str
  aggregation_type: str
  __post_init__()

class abacusai.api_class._AlertConditionConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'alert_type'
  config_class_key_value_camel_case = True
  config_class_map

class abacusai.api_class.AlertActionConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  action_type: abacusai.api_class.enums.AlertActionType
  classmethod _get_builder()

class abacusai.api_class.EmailActionConfig

  Bases: `AlertActionConfig`

  Email Action Config for Monitor Alerts

  Parameters:

    - email_recipients (List[str]) – List of email addresses to send the alert to.

    - email_body (str) – Body of the email to send.

  email_recipients: List[str]
  email_body: str
  __post_init__()

class abacusai.api_class._AlertActionConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'action_type'
  config_class_map

class abacusai.api_class.MonitorThresholdConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Monitor Threshold Config for Monitor Alerts

  Parameters:

    - drift_type (FeatureDriftType) – Feature drift type to apply the threshold on to determine whether a column has drifted significantly enough to be a violation.

    - threshold_config (ThresholdConfigs) – Thresholds for when to consider a column to be in violation. The alert will only fire when the drift value is strictly greater than the threshold.

  drift_type: abacusai.api_class.enums.FeatureDriftType
  at_risk_threshold: float
  severely_drifting_threshold: float
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.FeatureMappingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  feature_name: str
  feature_mapping: str
  nested_feature_name: str

class abacusai.api_class.ProjectFeatureGroupTypeMappingsConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  feature_group_id: str
  feature_group_type: str
  feature_mappings: List[FeatureMappingConfig]
  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.PythonFunctionArgument

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionArgumentType) – The type of the python function argument

    - name (str) – The name of the python function variable

    - is_required (bool) – Whether the argument is required

    - value (Any) – The value of the argument

    - pipeline_variable (str) – The name of the pipeline variable to use as the value

  variable_type: abacusai.api_class.enums.PythonFunctionArgumentType
  name: str
  is_required: bool
  value: Any
  pipeline_variable: str

class abacusai.api_class.OutputVariableMapping

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionOutputArgumentType) – The type of the python function output argument

    - name (str) – The name of the python function variable

  variable_type: abacusai.api_class.enums.PythonFunctionOutputArgumentType
  name: str

class abacusai.api_class.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str) –

  __setitem__(item, value)
    Parameters:

      - item (str) –

      - value (Any) –

  _unset_item(item)
    Parameters:

      item (str) –

  get(item, default=None)
    Parameters:

      - item (str) –

      - default (Any) –

  pop(item, default=NotImplemented)
    Parameters:

      - item (str) –

      - default (Any) –

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass

class abacusai.api_class.FeatureGroupExportConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  connector_type: abacusai.api_class.enums.ConnectorType
  classmethod _get_builder()

class abacusai.api_class.FileConnectorExportConfig

  Bases: `FeatureGroupExportConfig`

  Helper class that provides a standard way to create an ABC using inheritance.

  location: str
  export_file_format: str
  __post_init__()
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.DatabaseConnectorExportConfig

  Bases: `FeatureGroupExportConfig`

  Helper class that provides a standard way to create an ABC using inheritance.

  database_connector_id: str
  mode: str
  object_name: str
  id_column: str
  additional_id_columns: List[str]
  data_columns: Dict[str, str]
  __post_init__()
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class._FeatureGroupExportConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'connector_type'
  config_class_map